/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kafka.clients.admin;

/**
 * Options for {@link Admin#expireDelegationToken(byte[], ExpireDelegationTokenOptions)}.
 */
public class ExpireDelegationTokenOptions extends AbstractOptions<ExpireDelegationTokenOptions> {
    private long expiryTimePeriodMs = -1L;

    /**
     * @param expiryTimePeriodMs the time period until we should expire this token.
     * {@code expiryTimePeriodMs} &gt;= 0: the token will update the expiration timestamp to min(now + expiryTimePeriodMs, maxTimestamp)
     * {@code expiryTimePeriodMs} &lt; 0: token will be expired immediately.
     */
    public ExpireDelegationTokenOptions expiryTimePeriodMs(
        long expiryTimePeriodMs
    ) {
        this.expiryTimePeriodMs = expiryTimePeriodMs;
        return this;
    }

    public long expiryTimePeriodMs() {
        return expiryTimePeriodMs;
    }
}
